@@ -6,9 +6,11 @@
 @Desc    : 
 """
 
-__version__ = '0.0.12'
-
 from ytools.log import logger
+from ytools.version import get_version
+from ytools.utils.magic import empty
+
+__version__ = get_version(path=__file__)
 
 if __name__ == '__main__':
     pass
